AddMenuSectionEntryToFavoritesResponse class
- Inheritance
-
- Object
- GenericResponse
- AddMenuSectionEntryToFavoritesResponse
Constructors
-
AddMenuSectionEntryToFavoritesResponse(dynamic statusCode, Map<
String, dynamic> ? validationError) - AddMenuSectionEntryToFavoritesResponse.fromResponse(Response response)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode ↔ int
-
getter/setter pairinherited
-
validationError
↔ Map<
String, dynamic> ? -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited