GenericResponse class
- Implementers
- AddMenuSectionEntryToFavoritesResponse
- CompanyResponse
- ConfirmEmailResponse
- ConfirmPhoneNumberResponse
- LoginResponse
- MenuSectionEntriesResponse
- MenuSectionResponse
- MFASwitchResponse
- NodesListResponse
- OrderCreateResponse
- OrdersListResponse
- OtpStatusResponse
- PasswordResetResponse
- RegisterResponse
- RemoveMenuSectionEntryFromFavoritesResponse
- TokenRefreshResponse
- TransactionCreateResponse
- TransactionsResponse
- UpdatePasswordResponse
- UserDataResponse
Constructors
- GenericResponse(int statusCode)
- GenericResponse.fromResponse(Response response)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited