LoginResponse class

Inheritance

Constructors

LoginResponse(dynamic statusCode, String? accessToken, String? refreshToken)
LoginResponse.fromResponse(Response response)

Properties

accessToken String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
refreshToken String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited