MFASwitchResponse class
- Inheritance
-
- Object
- GenericResponse
- MFASwitchResponse
Constructors
- MFASwitchResponse(dynamic statusCode, String? validationError)
- MFASwitchResponse.fromResponse(Response response)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- mfaUrl ↔ String?
-
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secretKey ↔ String?
-
latefinal
- statusCode ↔ int
-
getter/setter pairinherited
- validationError ↔ String?
-
latefinal
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited