OrderCreateResponse class

Inheritance

Constructors

OrderCreateResponse(dynamic statusCode, Order? order, Map<String, dynamic>? validationError)
OrderCreateResponse.fromResponse(Response response)

Properties

hashCode int
The hash code for this object.
no setterinherited
order Order?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
getter/setter pairinherited
validationError Map<String, dynamic>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited