TokenRefreshResponse class
- Inheritance
-
- Object
- GenericResponse
- TokenRefreshResponse
Constructors
- TokenRefreshResponse(dynamic statusCode, String? refreshedAccessToken)
- TokenRefreshResponse.fromResponse(Response response)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- refreshedAccessToken ↔ String?
-
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode ↔ int
-
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited