TransactionsResponse class
- Inheritance
-
- Object
- GenericResponse
- TransactionsResponse
Constructors
-
TransactionsResponse(dynamic statusCode, List<
Transaction> ? transactions, String? validationError) - TransactionsResponse.fromResponse(Response response)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode ↔ int
-
getter/setter pairinherited
-
transactions
↔ List<
Transaction> ? -
getter/setter pair
- validationError ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited