Asset class
- Inheritance
-
- Object
- BaseModel
- TranslatableModel
- Asset
Constructors
- Asset.fromJson(dynamic json)
Properties
- assetType ↔ AssetType
-
getter/setter pair
- barcode ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- id ↔ String
-
getter/setter pairinherited
-
images
↔ List<
String> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
translations
↔ Map<
String, Map< String, String> > -
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override