Transaction class

Inheritance

Constructors

Transaction.fromJson(dynamic json)

Properties

entries List<TransactionEntry>
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
id String
getter/setter pairinherited
orderEntry OrderEntry
getter/setter pair
orderEntryToCompensateFor OrderEntry
getter/setter pair
orderEntryToPayFor OrderEntry
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source Node
getter/setter pair
target Node
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override