Offer class

Inheritance

Constructors

Offer.fromJson(dynamic json)

Properties

assetNames → dynamic
no setter
hashCode int
The hash code for this object.
no setteroverride
id String
getter/setter pairinherited
images → dynamic
no setter
incomeNode Node?
getter/setter pair
incomeTransactionTemplate TransactionTemplate
getter/setter pair
outcomeNode Node?
getter/setter pair
outcomeTransactionTemplate TransactionTemplate
getter/setter pair
prices → dynamic
no setter
rating double
getter/setter pair
reserve int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userRating double?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override