OrderEntry class

Inheritance

Constructors

OrderEntry.fromJson(dynamic json)

Properties

amount int
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
id String
getter/setter pairinherited
incomeNode Node
getter/setter pair
offer Offer
getter/setter pair
offerObject Offer?
getter/setter pair
outcomeNode Node
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override