TransactionCreateResponse class

Inheritance

Constructors

TransactionCreateResponse(dynamic statusCode, Transaction? transaction, Map<String, dynamic>? validationError)
TransactionCreateResponse.fromResponse(Response response)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
getter/setter pairinherited
transaction Transaction?
getter/setter pair
validationError Map<String, dynamic>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited